@@ -55,7 +55,7 @@ class BaseTrackedModel(BaseModel):
 
     def __init__(self, *args, **kwargs):
         super(BaseTrackedModel, self).__init__(*args, **kwargs)
-        if self.editor and not self.creator:
+        if self.editor and not self.creator: #TODO move this to save
             self.creator = self.editor
 
     @classmethod
