@@ -1,6 +1,7 @@
 import os
 from os.path import dirname, join
 from django.conf import settings
+from django.db.models import Q
 
 from crud_framework.errors import Error, HttpStatus
 from crud_framework.schemas.base import BaseSchema
@@ -63,7 +64,8 @@ class CrudSchema(BaseSchema):
         self.q_filters = q_filters if q_filters else []
 
     def get_queryset(self):
-        return self.model_class.objects.filter(**self.filters, *self.q_filters).order_by(*self.ORDER_BY)
+        queryset = self.model_class.objects.filter(*self.q_filters, **self.filters).order_by(*self.ORDER_BY)
+        return queryset
 
     def get(self):
         if not (self.GET or self.POST or self.PUT):
